@@ -2,8 +2,9 @@ package utf8::all;
 use strict;
 use warnings;
 use 5.010; # state
+
 # ABSTRACT: turn on Unicode - all of it
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 
 use Import::Into;
@@ -13,14 +14,7 @@ use Symbol qw(qualify_to_ref);
 # Holds the pointers to the original version of redefined functions
 state %_orig_functions;
 
-my @KNOWN_OPTIONS = qw( File::Find Cwd ); # :all is a "tag"
 sub import {
-    my %options = map { $_ => 1 } @_[1 .. $#_]; # First entry in @_ is __PACKAGE__
-    if (delete $options{':all'}) {
-        $options{$_} = 1 for @KNOWN_OPTIONS;
-    }
-    %options = %options{@KNOWN_OPTIONS}; # only keep known opts
-
     # Enable features/pragmas in calling package
     my $target = caller;
     'utf8'->import::into($target);
@@ -30,7 +24,7 @@ sub import {
     'feature'->import::into($target, qw{unicode_strings}) if $^V >= v5.11.0;
     'feature'->import::into($target, qw{unicode_eval fc}) if $^V >= v5.16.0;
 
-    unless ($^O eq 'Win32') {
+    unless ($^O =~ /MSWin32|cygwin|dos|os2/) {
         no strict qw(refs); ## no critic (TestingAndDebugging::ProhibitNoStrict)
         no warnings qw(redefine);
 
@@ -41,42 +35,17 @@ sub import {
         # Replace glob with utf8 aware version
         *{$target . '::glob'} = \&_utf8_glob;
         $^H{'utf8::all::glob'} = 1;
-
-        # List of redefined non-core functions
-        my @redefined;
-
-        if ($options{'Cwd'}) {
-            require Cwd;
-            push @redefined, map "Cwd::$_" => qw(
-                cwd fastcwd getcwd fastgetcwd
-                abs_path realpath fast_abs_path
-            );
-        }
-
-        if ($options{'File::Find'}) {
-            require File::Find;
-            push @redefined, map "File::Find::$_" => qw(find finddepth);
-        }
-
-        for my $f (@redefined) {
-            $^H{"utf8::all::$f"} = 1;
-            # If we already have the _orig_function, we have redefined the function
-            # in an earlier load of the module, so we need not do it again
-            unless ($_orig_functions{$f}) {
-                $_orig_functions{$f} = \&{$f};
-                if ($f =~ /^File::Find::(find|finddepth)$/) {
-                    *{$f} = \&{"_utf8_$1"};
-                } else {
-                    *{$f} = sub { return _utf8_simple_func($f, @_); };
-                }
-            }
-        }
     }
 
-    # Make @ARGV utf-8 when called from the main package
-    state $have_encoded_argv = 0;
-    if ($target eq 'main' && !$have_encoded_argv++) {
-        $_ = Encode::decode('UTF-8' ,$_) for @ARGV;
+    # Make @ARGV utf-8 when called from the main package, unless perl was launched
+    # with the -CA flag as this already has @ARGV decoded automatically.
+    # -CA is active if the the fifth bit (32) of the ${^UNICODE} variable is set.
+    # (see perlrun on the -C command switch for details about ${^UNICODE})
+    if (!(${^UNICODE} & 32)) {
+        state $have_encoded_argv = 0;
+        if ($target eq 'main' && !$have_encoded_argv++) {
+            $_ = Encode::decode('UTF-8' ,$_) for @ARGV;
+        }
     }
 
     $^H{'utf8::all'} = 1;
@@ -84,23 +53,6 @@ sub import {
     return;
 }
 
-sub _utf8_simple_func {
-    my $func = shift;
-    my $hints = (caller 1)[10]; # Use caller level 1 because of the added anonymous sub around call
-    if (not $hints->{"utf8::all::$func"}) {
-        return $_orig_functions{$func}->(@_);
-    }
-    elsif (wantarray) {
-        return map { Encode::decode('UTF-8' ,$_) }
-            $_orig_functions{$func}->( map { Encode::encode('UTF-8', $_) } @_ );
-    }
-    else {
-        return Encode::decode('UTF-8',
-            $_orig_functions{$func}->(map { Encode::encode('UTF-8', $_) } @_)
-        );
-    }
-}
-
 sub _utf8_readdir(*) { ## no critic (Subroutines::ProhibitSubroutinePrototypes)
     my $pre_handle = shift;
     my $handle = ref($pre_handle) ? $pre_handle : qualify_to_ref($pre_handle, caller);
@@ -129,39 +81,6 @@ sub _utf8_glob {
     }
 }
 
-sub _utf8_find {
-    my $ref = shift; # This can be the wanted function or a find options hash
-    #  Make argument always into the find's options hash
-    my %find_options_hash = ref($ref) eq "HASH" ? %$ref : (wanted => $ref);
-    my $wanted = $find_options_hash{wanted}; # The original wanted function
-    # Get the hint from the caller (one level deeper if called from _utf8_finddepth)
-    my $hints = ((caller 1)[3]//"") ne 'utf8::all::_utf8_finddepth' ? (caller 0)[10] : (caller 1)[10];
-    if (not $hints->{'utf8::all::File::Find::find'}) {
-        return $_orig_functions{"File::Find::find"}->(\%find_options_hash, @_);
-    } else {
-        $find_options_hash{wanted} = sub {
-            # Decode the file variables
-            local $_                    = Encode::decode('UTF-8', $_);
-            local $File::Find::name     = Encode::decode('UTF-8', $File::Find::name);
-            local $File::Find::dir      = Encode::decode('UTF-8', $File::Find::dir);
-            local $File::Find::fullname = Encode::decode('UTF-8', $File::Find::fullname);
-            local $File::Find::topdir   = Encode::decode('UTF-8', $File::Find::topdir);
-            local $File::Find::topdev   = Encode::decode('UTF-8', $File::Find::topdev);
-            local $File::Find::topino   = Encode::decode('UTF-8', $File::Find::topino);
-            local $File::Find::topmode  = Encode::decode('UTF-8', $File::Find::topmode);
-            local $File::Find::topnlink = Encode::decode('UTF-8', $File::Find::topnlink);
-            $wanted->();
-        };
-        return $_orig_functions{"File::Find::find"}->(\%find_options_hash, map { Encode::encode('UTF-8', $_) } @_);
-    }
-}
-
-sub _utf8_finddepth {
-    my $ref = shift; # This can be the wanted function or a find options hash
-    return _utf8_find( { bydepth => 1, ref($ref) eq "HASH" ? %$ref : (wanted => $ref) }, @_);
-}
-
-
 
 1;
 
@@ -177,17 +96,12 @@ utf8::all - turn on Unicode - all of it
 
 =head1 VERSION
 
-version 0.014
+version 0.016
 
 =head1 SYNOPSIS
 
     use utf8::all;                # Turn on UTF-8, all of it.
 
-    # Also provide UTF-8 versions of functions from...
-    use utf8::all qw(File::Find); # File::Find
-    use utf8::all qw(Cwd);        # Cwd
-    use utf8::all qw(:all);       # everything
-
     open my $in, '<', 'contains-utf8';  # UTF-8 already turned on here
     print length 'føø bār';             # 7 UTF-8 characters
     my $utf8_arg = shift @ARGV;         # @ARGV is UTF-8 too (only for main)
@@ -218,38 +132,15 @@ Unicode characters based on names.
 
 =item *
 
-readdir now returns UTF-8
+readdir now returns UTF-8 characters instead of bytes.
 
 =item *
 
-L<glob|perlfunc/glob> and the C<< <> >> operator
+L<glob|perlfunc/glob> and the C<< <> >> operator now return UTF-8
+characters instead of bytes.
 
 =back
 
-=head1 Import options
-
-If you provide the C<File::Find> or C<Cwd> options to the
-C<use utf8::all> line, those modules are loaded if they haven't
-been already, but you will get UTF-8-ified versions instead of the
-normal ones. This effect is lexical.
-
-=over 4
-
-=item L<File::Find>
-
-C<find> and C<finddepth>
-
-=item L<Cwd>
-
-C<wd>, C<fastcwd>, C<getcwd>, C<fastgetcwd>
-
-C<abs_path>, C<realpath>, C<fast_abs_path>
-
-=back
-
-Use C<use utf8::all qw(:all)> to get all of these, plus whatever
-we dream up in the future.
-
 =head2 Lexical scope
 
 The pragma is lexically-scoped, so you can do the following if you had
@@ -266,6 +157,20 @@ some reason to:
     my $text = do { local $/; <$in>};
     print length $text, "\n";         # 10, not 7!
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<File::Find::utf8> for fully utf-8 aware File::Find functions.
+
+=item *
+
+L<Cwd::utf8> for fully utf-8 aware Cwd functions.
+
+=back
+
 =head1 INTERACTION WITH AUTODIE
 
 If you use L<autodie>, which is a great idea, you need to use at least version
@@ -292,6 +197,12 @@ and may be cloned from L<git://github.com/doherty/utf8-all.git>
 You can make new bug reports, and view existing ones, through the
 web interface at L<https://github.com/doherty/utf8-all/issues>.
 
+=head1 COMPATIBILITY
+
+The filesystems of Dos, Windows, and OS/2 do not (fully) support
+UTF-8. The C<readdir> function and C<glob> operators will therefore not
+be replaced on these systems.
+
 =head1 AUTHORS
 
 =over 4
